﻿function Install-ChocolateyPackage {
param(
  [string] $packageName, 
  [string] $fileType = 'exe',
  [string] $silentArgs = '',
  [string] $url,
  [string] $url64bit = $url,
  $validExitCodes = @(0),
  [string]$fileName = "$($packageName)Install.$fileType" ,
  [string]$fileName64 = $fileName  
)
  
  try {

  
    Write-Debug "Running 'Install-ChocolateyPackage' for $packageName with url:`'$url`', args: `'$silentArgs`' ";


    $chocTempDir = Join-Path $env:TEMP "chocolatey"
    $tempDir = Join-Path $chocTempDir "$packageName"
    if (![System.IO.Directory]::Exists($tempDir)) {[System.IO.Directory]::CreateDirectory($tempDir) | Out-Null}
    $file = Join-Path $tempDir $fileName64
  
    Get-ChocolateyWebFile $packageName $file $url $url64bit
    Install-ChocolateyInstallPackage $packageName $fileType $silentArgs $file -validExitCodes $validExitCodes
    Write-ChocolateySuccess $packageName
  } catch {
    Write-ChocolateyFailure $packageName $($_.Exception.Message)
    throw 
  }
}





try { 
	$processor = Get-WmiObject Win32_Processor
	$is64bit = $processor.AddressWidth -eq 64
	$mydir = (Split-Path -parent $MyInvocation.MyCommand.Definition)
	$contentDir = ($mydir | Split-Path | Join-Path -ChildPath "content")
	$binDir = ($mydir | Split-Path | Join-Path -ChildPath "bin")
	$toolsDir = ($mydir | Split-Path | Join-Path -ChildPath "tools")
	$shortcutTarget = Join-Path $binDir "$packageName.exe"

	Import-Module "$toolsDir\DeploymentUtils.psm1"

	   Install-ChocolateyPackage -packageName "$packageName" `
   						-fileType 'msi' `
   						-url 'http://visualstudiogallery.msdn.microsoft.com/b1ef7eb2-e084-4cb8-9bc7-06c3bad9148f/file/83775/3/Visual%20Studio%20Team%20Foundation%20Server%202012%20Update%202%20Power%20Tools.msi' `
   						-silentArgs '/quiet /norestart' `
   						 -fileName 'Visual Studio Team Foundation Server 2012 Update 2 Power Tools.msi' 
   						#-url64bit '' `
   						#-validExitCodes 
  
} catch {
	Write-ChocolateyFailure $packageName "$($_.Exception.Message)"
	throw 
}
